@@ -110,6 +110,8 @@ class ProxyManager:
                 try:
                     task = self._executor_queue.get(False, timeout=1)
                     task()
+
+                    self._executor_queue.task_done()
                 except Empty:
                     time.sleep(1)
                     continue
@@ -121,6 +123,8 @@ class ProxyManager:
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
+        self._executor_queue.join()
+
         self._executor_running = False
         self._executor.shutdown(True)
 
